==> potatotodo-1.0.7.tar.gz: potatotodo-1.0.7/README.md <==
# Hello, we are potato team!

## Introduce
we develop **potatotodo** (this is todo_list !)  
todo_list's **function** : todo **what?**, set a **category**, Set a **period** and **done?** 

we develop for who can use console  
**but if you can't use console don't worry we prepared --help**

# How to download
first you nead**python(version>=3.6)**    
second you have yo download pip **(python install pip)**  
third jusy download! **(python install potatotodo)**

If you prepare all but you can't download please typing this -> **pip3 install potatotodo**


## --help  
potato =           Print All.  
potato --help =    Show this message and exit.  
potato --mk =      Make a new plan: [descr.] [due] [category]  
potato --rm =      Remove your plan: [number]  
potato --mod =     modofy your plan: [number]  
potato --find =    Find your plan: [text]  
potato --det =     Show details of plan: [number]  
potato --pg =      Print the page of which tou enter: [page]  
potato --cat =     Print the plans for category which you will selcet  
potato --uf =      Print your unfinished plans  
potato --f =       Print your finished plans  

### If you need more information please comment here or refer to setup.py !


### Developers
[Hyunjun Lee](https://github.com/Alpacadabra/to-do-list) , [Kim Yejun](https://github.com/kyj0701/to-do-list) , [Lee je shin](https://github.com/BeautifulTommorow/to-do-list) , [lee hye jin](https://github.com/bean3/to-do-list) , [Kim tae O](https://github.com/xodh/to-do-list)

==> potatotodo-1.0.8.tar.gz: potatotodo-1.0.8/README.md <==
# Hello, we are potato team!

## Introduce
we develop **potatotodo** (this is todo_list !)  
todo_list's **function** : todo **what?**, set a **category**, Set a **period** and **done?** 

we develop for who can use console  
**but if you can't use console don't worry we prepared --help**

# How to download
first you nead**python(version>=3.6)**    
second you have yo download pip **(python install pip)**  
third you have to download colorama **(pip install colorama)**  
finally jusy download! **(python install potatotodo)**

If you prepare all but you can't download please typing this -> **pip3 install potatotodo**  

# How to upgrade  
just typing -> **(pip install —upgrade potatotodo)**  
if do not work, please typing -> **(pip uninstall potatotodo)**  

## --help  
potato =           Print All.  
potato --help =    Show this message and exit.  
potato --mk =      Make a new plan: [descr.] [due] [category]  
potato --rm =      Remove your plan: [number]  
potato --mod =     modofy your plan: [number]  
potato --find =    Find your plan: [text]  
potato --det =     Show details of plan: [number]  
potato --pg =      Print the page of which tou enter: [page]  
potato --cat =     Print the plans for category which you will selcet  
potato --uf =      Print your unfinished plans  
potato --f =       Print your finished plans  

### If you need more information please comment here or refer to setup.py !
[LICENSE](https://github.com/bean3/to-do-list/blob/master/LICENSE)

### Developers
[Hyunjun Lee](https://github.com/Alpacadabra/to-do-list) , [Kim Yejun](https://github.com/kyj0701/to-do-list) , [Lee je shin](https://github.com/BeautifulTommorow/to-do-list) , [lee hye jin](https://github.com/bean3/to-do-list) , [Kim tae O](https://github.com/xodh/to-do-list)
